@@ -16,7 +16,7 @@ void sampD(int *offid, int noff, Matrix<double> X_design_GD [], int *npar, int *
         double mean_vec;
         double n;
         double N;
-        int dsmatch[noff];
+        int *dsmatch = new int[noff];
 
          
          Matrix<double> betaDus (npar[0],1); 
